@@ -58,7 +58,7 @@ class Algorithm(Resource):
     _fields = {
         # 资源创建/更新请求包体中必须包含且不能为空的字段
         'required': {
-            'create': ['name', 'filename', 'mirror_id'],
+            'create': ['name', 'mirror_id'],
             'update': ['id', 'name'],
         },
         # 资源创建/更新请求包体中包含的所有字段
@@ -68,7 +68,7 @@ class Algorithm(Resource):
                        'follows_anylearn_norm'],
             'update': ['id', 'name', 'description', 'public', 
                        'tags', 'mirror_id', 'train_params',
-                       'follows_anylearn_norm'],
+                       'follows_anylearn_norm', 'filename'],
         },
     }
     """
